diff --git a/buildnum.properties b/buildnum.properties
index 92d794e..e2384e0 100644
--- a/buildnum.properties
+++ b/buildnum.properties
@@ -1,3 +1,3 @@
#ANT Task: ch.oscg.jreleaseinfo.BuildNumberHandler
-#Mon Apr 16 15:39:07 GMT 2007
-build.num.last=68
+#Wed Jul 18 23:09:10 PDT 2007
+build.num.last=70
diff --git a/lib/pircbot.jar b/lib/pircbot.jar
index 191708b..95cce20 100644
Binary files a/lib/pircbot.jar and b/lib/pircbot.jar differ
diff --git a/mobibot.iml b/mobibot.iml
index b2c00bb..e2b6c5b 100644
--- a/mobibot.iml
+++ b/mobibot.iml
@@ -9,15 +9,6 @@
-
-
-
-
-
-
-
-
-
@@ -162,6 +153,15 @@
+
+
+
+
+
+
+
+
+
diff --git a/mobibot.ipr b/mobibot.ipr
index e7307d9..aa52879 100644
--- a/mobibot.ipr
+++ b/mobibot.ipr
@@ -569,7 +569,7 @@
-
+
diff --git a/mobibot.iws b/mobibot.iws
index 2078d14..e119676 100644
--- a/mobibot.iws
+++ b/mobibot.iws
@@ -19,11 +19,12 @@
-
-
-
-
+
+
+
+
+
@@ -153,19 +154,19 @@
-
+
-
+
-
+
-
+
@@ -252,6 +253,10 @@
+
+
+
+
@@ -321,20 +326,6 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
@@ -362,11 +353,11 @@
-
+
-
+
@@ -432,48 +423,6 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
@@ -495,6 +444,51 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -717,7 +711,7 @@
-
+
@@ -774,9 +768,9 @@
-
+
-
+
@@ -802,9 +796,9 @@
-
+
-
+
diff --git a/src/net/thauvin/erik/mobibot/Mobibot.java b/src/net/thauvin/erik/mobibot/Mobibot.java
index e8e34ac..e0a26f8 100644
--- a/src/net/thauvin/erik/mobibot/Mobibot.java
+++ b/src/net/thauvin/erik/mobibot/Mobibot.java
@@ -459,6 +459,11 @@ public class Mobibot extends PircBot
*/
private String _identNick = "";
+ /**
+ * The NickServ ident password.
+ */
+ private String _ident = "";
+
/**
* The ignored nicks array.
*/
@@ -583,7 +588,7 @@ public class Mobibot extends PircBot
options.addOption(HELP_ARG.substring(0, 1), HELP_ARG, false, "print this help message");
options.addOption(DEBUG_ARG.substring(0, 1), DEBUG_ARG, false,
"print debug & logging data directly to the console");
- options.addOption(OptionBuilder.withArgName("file").hasArg().withDescription("use alternate properties file")
+ options.addOption(OptionBuilder.hasArg().withDescription("use alternate properties file")
.withLongOpt(PROPS_ARG).create(PROPS_ARG.substring(0, 1)));
// Parse the command line
@@ -697,6 +702,7 @@ public class Mobibot extends PircBot
final String ignoredNicks = p.getProperty("ignore", "");
final String identNick = p.getProperty("ident-nick", "");
final String identMsg = p.getProperty("ident-msg", "");
+ final String ident = p.getProperty("ident", "");
final String tags = p.getProperty("tags", "");
// Get the del.icio.us properties
@@ -714,6 +720,9 @@ public class Mobibot extends PircBot
bot.setVersion(weblogURL);
bot.setMessageDelay(MESSAGE_DELAY);
+ // Set the ident password
+ bot.setIdent(ident);
+
// Set the ident nick and message
bot.setIdentNick(identNick);
bot.setIdentMsg(identMsg);
@@ -774,6 +783,13 @@ public class Mobibot extends PircBot
bot.setVersion(INFO_STRS[0]);
+ // Identify with NickServ
+ if (isValidString(ident))
+ {
+ bot.identify(ident);
+ }
+
+ // Identify with a specified nick
if (isValidString(identNick) && isValidString(identMsg))
{
bot.sendMessage(identNick, identMsg);
@@ -1142,6 +1158,11 @@ public class Mobibot extends PircBot
setVersion(INFO_STRS[0]);
+ if (isValidString(_ident))
+ {
+ identify(_ident);
+ }
+
if (isValidString(_identNick) && isValidString(_identMsg))
{
sendMessage(_identNick, _identMsg);
@@ -2800,6 +2821,17 @@ public class Mobibot extends PircBot
_googleKey = googleKey;
}
+ /**
+ * Sets the ident password.
+ *
+ * @param pwd The password.
+ */
+ private void setIdent(String pwd)
+ {
+ _ident = pwd;
+ }
+
+
/**
* Sets the ident message.
*
diff --git a/src/net/thauvin/erik/mobibot/ReleaseInfo.java b/src/net/thauvin/erik/mobibot/ReleaseInfo.java
index 8d43e1f..f764f64 100644
--- a/src/net/thauvin/erik/mobibot/ReleaseInfo.java
+++ b/src/net/thauvin/erik/mobibot/ReleaseInfo.java
@@ -1,5 +1,5 @@
/* Created by JReleaseInfo AntTask from Open Source Competence Group */
-/* Creation date Mon Apr 16 15:39:07 GMT 2007 */
+/* Creation date Wed Jul 18 23:09:10 PDT 2007 */
package net.thauvin.erik.mobibot;
import java.util.Date;
@@ -20,31 +20,21 @@ public class ReleaseInfo {
}
- /** buildDate (set during build process to 1176737947817L). */
- private static final Date buildDate = new Date(1176737947817L);
+ /** buildDate (set during build process to 1184825350594L). */
+ private static final Date buildDate = new Date(1184825350594L);
/**
- * Get buildDate (set during build process to Mon Apr 16 15:39:07 GMT 2007).
+ * Get buildDate (set during build process to Wed Jul 18 23:09:10 PDT 2007).
* @return Date buildDate
*/
public static Date getBuildDate() { return buildDate; }
/**
* Get buildNumber (set during build process to 68).
* @return int buildNumber
*/
- public static int getBuildNumber() { return 68; }
-
-
- /** version (set during build process to "0.3"). */
- private static final String version = "0.3";
-
- /**
- * Get version (set during build process to "0.3").
- * @return String version
- */
- public static String getVersion() { return version; }
+ public static int getBuildNumber() { return 70; }
/** project (set during build process to "mobibot"). */
@@ -56,4 +46,14 @@ public class ReleaseInfo {
*/
public static String getProject() { return project; }
+
+ /** version (set during build process to "0.3"). */
+ private static final String version = "0.3";
+
+ /**
+ * Get version (set during build process to "0.3").
+ * @return String version
+ */
+ public static String getVersion() { return version; }
+
}
@@ -20,31 +20,21 @@ public class ReleaseInfo {
public static Date getBuildDate() { return buildDate; }
/**
- * Get buildNumber (set during build process to 68).
+ * Get buildNumber (set during build process to 70).
* @return int buildNumber
*/